﻿using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Pdf.Actions;
using GrapeCity.Documents.Pdf.Annotations;
using GrapeCity.Documents.Text;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Text.RegularExpressions;

namespace DesignFieldsForm
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("Generating PDF Form Template...");

            // Create new PDF Document 
            var doc = new GcPdfDocument();
            var page = doc.NewPage();
            var g = page.Graphics;

            // Pen for drawing rectangles
            GrapeCity.Documents.Drawing.Pen rec_pen = new GrapeCity.Documents.Drawing.Pen(Color.Transparent);

            // First rectangle to represent page
            var rect1 = new RectangleF(22, 22, page.Size.Width - 22, page.Size.Height - 22);
            g.DrawRectangle(rect1, rec_pen);

            // Second rectangle to represent Company logo, Form Title
            var rect2 = new RectangleF(22, 22, rect1.Size.Width - 22, 100);
            g.DrawRectangle(rect2, rec_pen);           

            // Render Company Logo
            var image = GrapeCity.Documents.Drawing.Image.FromFile(Path.Combine("Resources", "Images", "vacaymode.png"));
            RectangleF imgBounds = new RectangleF(27F, 22F, 100, 100);
            g.DrawImage(image, imgBounds, null, ImageAlign.ScaleImage);

            // Render Form Title
            TextFormat tf1 = new TextFormat();
            tf1.FontSize = 20;          
            tf1.FontName = "Segoe UI";
            RectangleF titleBounds = new RectangleF(180F, 50F, 200, 100);
            g.DrawString("BOOKING FORM", tf1, titleBounds, TextAlignment.Center);            

            // Third rectangle to contain Form Fields and its labels          
            var rect3 = new RectangleF(22, 130, rect1.Size.Width - 22, 640);
            g.DrawRectangle(rect3, rec_pen);          

            // TextFormat to render section titles in form
            TextFormat tf3 = new TextFormat();
            tf3.FontName = "Arial";
            tf3.FontSize = 14;
            tf3.FontBold = true;

            // TextFormat to render field labels in form
            TextFormat tf4 = new TextFormat();
            tf4.FontName = "Arial";
            tf4.FontSize = 14;

            PointF ip2 = new PointF(30, 135);
            float dY1 = 32;

            // Rectangle for form section "Tour Details"
            var rect4 = new RectangleF(27, 135, rect3.Size.Width - 10, 18);
            g.DrawRectangle(rect4, rec_pen);           
            g.DrawString("Tour Details", tf3, new PointF(ip2.X, ip2.Y + 1));

            ip2.X += 10;

            // Combobox field: Departure            
            ip2.Y += dY1;
            g.DrawString("Departure:", tf4, ip2);

            // Combobox field: Destination
            ip2.Y += dY1;
            g.DrawString("Destination:", tf4, ip2);

            // Text field: Departure Date:
            ip2.Y += dY1;
            g.DrawString("Departure Date:", tf4, ip2);

            // Text field: Return Date:
            ip2.Y += dY1;
            g.DrawString("Return Date:", tf4, ip2);

            // Rectangle for form section "Contact Details"
            ip2.Y += dY1 + 10;
            var rect5 = new RectangleF(27, ip2.Y, rect3.Size.Width - 10, 18);
            g.DrawRectangle(rect5, rec_pen);          
            g.DrawString("Contact Details", tf3, new PointF(ip2.X - 10, ip2.Y + 1));

            // Text field: Name
            ip2.Y += dY1;
            g.DrawString("Name:", tf4, ip2);

            // Text field: Address
            ip2.Y += dY1;
            g.DrawString("Address:", tf4, ip2);

            // Text field: Phone
            ip2.Y += dY1;
            g.DrawString("Phone:", tf4, ip2);

            // Text field: Email
            ip2.Y += dY1;
            g.DrawString("Email:", tf4, ip2);

            // Rectangle for form section "Other Details"
            ip2.Y += dY1 + 10;
            var rect6 = new RectangleF(27, ip2.Y, rect3.Size.Width - 10, 18);
            g.DrawRectangle(rect6, rec_pen);        
            g.DrawString("Other Details", tf3, new PointF(ip2.X - 10, ip2.Y + 1));

            // Checkbox: Other Services Needed 
            ip2.Y += dY1;
            g.DrawString("Other Services Needed:", tf4, ip2);
            ip2.Y += dY1;
            ip2.X += 20;
            g.DrawString("Flights", tf4, ip2);
            ip2.X += 80;
            g.DrawString("Rental Car", tf4, ip2);
            ip2.X += 100;
            g.DrawString("Hotels", tf4, ip2);
            ip2.X += 80;
            g.DrawString("Entertainment", tf4, ip2);

            // Radio Button: Travel Insurance
            ip2.X = 40;
            ip2.Y += dY1;
            g.DrawString("Do you want travel Insurance ?", tf4, ip2);
            ip2.Y += dY1;
            ip2.X += 20;
            g.DrawString("Yes", tf4, ip2);
            ip2.X += 80;
            g.DrawString("No", tf4, ip2);

            // Text Area: Rectangle for form section "Special Requests"
            ip2.X = 40;
            ip2.Y += dY1 + 10;
            var rect7 = new RectangleF(27, ip2.Y, rect3.Size.Width - 10, 18);
            g.DrawRectangle(rect7, rec_pen);        
            g.DrawString("Do you have any special requests, example golf, diving, sailing, skiing", tf3, new PointF(ip2.X - 10, ip2.Y + 1));

            // Save PDF Form template
            doc.Save("FormLayout.pdf");

            Console.WriteLine("PDF File saved !!!");
            Console.WriteLine("Press any key to exit....");
            Console.ReadKey();
        }
    }
}
